==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/netelements/crossings/with_tls/inspect_selected/linkindex2/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# Rebuild network
netedit.rebuildNetwork()

# zoom in central node
netedit.setZoom("50", "50", "50")

# go to select mode
netedit.selectMode()

# select first crossing
netedit.leftClick(referencePosition, 250, 225)

# select second crossing
netedit.leftClick(referencePosition, 415, 225)

# go to inspect mode
netedit.inspectMode()

# inspect first crossing
netedit.leftClick(referencePosition, 250, 225)

# Change linkindex2 with a non valid value
netedit.modifyAttribute(netedit.attrs.crossing.inspectSelectionTLS.linkIndex2, "dummylinkIndex", True)

# Change linkindex2 with a non valid value
netedit.modifyAttribute(netedit.attrs.crossing.inspectSelectionTLS.linkIndex2, "-3", True)

# Change linkindex2 with a valid value
netedit.modifyAttribute(netedit.attrs.crossing.inspectSelectionTLS.linkIndex2, "1", True)

# rebuild network
netedit.rebuildNetwork()

# Check undos
netedit.undo(referencePosition, 1)

# rebuild network
netedit.rebuildNetwork()

# Check redos
netedit.redo(referencePosition, 1)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/netelements/crossings/with_tls/inspect_selected/linkindex2/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# Rebuild network
netedit.rebuildNetwork()

# zoom in central node
netedit.setZoom("50", "50", "50")

# go to select mode
netedit.selectMode()

# select first crossing
netedit.leftClick(referencePosition, 250, 225)

# select second crossing
netedit.leftClick(referencePosition, 415, 225)

# go to inspect mode
netedit.inspectMode()

# inspect first crossing
netedit.leftClick(referencePosition, 250, 225)

# Change linkindex2 with a non valid value
netedit.modifyAttribute(netedit.attrs.crossing.inspectSelectionTLS.linkIndex2, "dummylinkIndex", True)

# Change linkindex2 with a non valid value
netedit.modifyAttribute(netedit.attrs.crossing.inspectSelectionTLS.linkIndex2, "-3", True)

# Change linkindex2 with a valid value
netedit.modifyAttribute(netedit.attrs.crossing.inspectSelectionTLS.linkIndex2, "1", True)

# rebuild network
netedit.rebuildNetwork()

# Check undos
netedit.undo(referencePosition, 1)

# rebuild network
netedit.rebuildNetwork()

# Check redos
netedit.redo(referencePosition, 1)

# save Netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
